@@ -3,6 +3,8 @@ from hexbytes import HexBytes
 from typing import NewType
 from enum import Enum
 from typing import Any
+from eth_account.datastructures import SignedTransaction
+from web3.types import TxReceipt
 
 
 class EidasLevelEnum(Enum):
@@ -13,7 +15,7 @@ class EidasLevelEnum(Enum):
     High = 4
 
 
-Transaction = NewType("Transaction", dict)  
+Transaction = NewType("Transaction", dict)
 Address = NewType("Address", str)
 TransactionHash = NewType("TransactionHash", str)  # TODO: CHECK RETURN TYPE
 
@@ -36,6 +38,7 @@ class AddKeyValidator(BaseModel):
     def get_dict(self) -> dict:
         return {k: str(v) for k, v in self.__dict__.items()}
 
+
 class AddIdentityIssuerValidator(BaseModel):
     network: NetworkValidator
     new_issuer_address: Address
@@ -48,7 +51,7 @@ class AddIdentityIssuerValidator(BaseModel):
 class AddIssuerCredentialValidator(BaseModel):
     network: NetworkValidator
     sig_credential: str
-    did:str
+    did: str
 
     def get_dict(self) -> dict:
         return {k: str(v) for k, v in self.__dict__.items()}
